==> ejc-ztpcct-impl-3.0.0-20230728.080333-12-sources.jar: com/ejianc/ztpc/bean/ConOrgDesignPlanEntity.java <==
package com.ejianc.ztpc.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 施工组织设计编制计划表
 * 
 * @author generator
 * 
 */
 @TableName("ct_con_org_design_plan")
public class ConOrgDesignPlanEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_state")
    private Integer billState; // 单据状态：0自由态，1已提交，2审批中，3审批通过，4驳回，5提交后有人审批中
    @TableField(value="project_id")
    private Long projectId; // 项目ID
    @TableField(value="project_code")
    private String projectCode; // 项目编码
    @TableField(value="project_name")
    private String projectName; // 项目名称
    @TableField(value="org_id")
    private Long orgId; // 项目组织ID
    @TableField(value="org_code")
    private String orgCode; // 项目组织编码
    @TableField(value="org_name")
    private String orgName; // 项目组织名称
    @TableField(value="parent_org_id")
    private Long parentOrgId; // 父级组织ID
    @TableField(value="parent_org_code")
    private String parentOrgCode; // 父级组织编码
    @TableField(value="parent_org_name")
    private String parentOrgName; // 父级组织名称
    @TableField(value="bill_code")
    private String billCode; // 文件编码
    @TableField(value="engineering_type_id")
    private Long engineeringTypeId; // 工程类别
    @TableField(value="file_name")
    private String fileName; // 文件名称
    @TableField(value="project_leave")
    private Long projectLeave; // 项目分级(自定义档案)
    @TableField(value="supervisor")
    private String supervisor; // 监理单位
    @TableField(value="chief_engineer_id")
    private Long chiefEngineerId; // 项目总工
    @TableField(value="chief_engineer")
    private String chiefEngineer; // 项目总工名称
    @TableField(value="designer")
    private String designer; // 设计单位
    @TableField(value="project_management_id")
    private Long projectManagementId; // 项目经理id
    @TableField(value="project_management_name")
    private String projectManagementName; // 项目经理
    @TableField(value="construct_id")
    private Long constructId; // 建设单位id
    @TableField(value="construct_name")
    private String constructName; // 建设单位
    @TableField(value="memo")
    private String memo; // 工程范围
    @TableField(value="classification")
    private String classification; // 专业分类
    @TableField(value="execute_state")
    private String executeState; // 执行状态
    @TableField(value="review_requirement")
    private String reviewRequirement; // 审查要求
    @TableField(value="edition")
    private String edition; // 版次
    @TableField(value="compile_person")
    private Long compilePerson; // 编制人
    @TableField(value="compile_person_name")
    private String compilePersonName; // 编制人名称
    @TableField(value="check_person")
    private Long checkPerson; // 审核人
    @TableField(value="check_person_name")
    private String checkPersonName; // 审核人名称
    @TableField(value="approver_person")
    private Long approverPerson; // 批准人
    @TableField(value="approver_person_name")
    private String approverPersonName; // 批准人名称
    
    
    

    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Long getParentOrgId() {
        return parentOrgId;
    }

    public void setParentOrgId(Long parentOrgId) {
        this.parentOrgId = parentOrgId;
    }
    public String getParentOrgCode() {
        return parentOrgCode;
    }

    public void setParentOrgCode(String parentOrgCode) {
        this.parentOrgCode = parentOrgCode;
    }
    public String getParentOrgName() {
        return parentOrgName;
    }

    public void setParentOrgName(String parentOrgName) {
        this.parentOrgName = parentOrgName;
    }
    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Long getEngineeringTypeId() {
        return engineeringTypeId;
    }

    public void setEngineeringTypeId(Long engineeringTypeId) {
        this.engineeringTypeId = engineeringTypeId;
    }
    public String getFileName() {
        return fileName;
    }

    public void setFileName(String fileName) {
        this.fileName = fileName;
    }
    public Long getProjectLeave() {
        return projectLeave;
    }

    public void setProjectLeave(Long projectLeave) {
        this.projectLeave = projectLeave;
    }
    public String getSupervisor() {
        return supervisor;
    }

    public void setSupervisor(String supervisor) {
        this.supervisor = supervisor;
    }
    public Long getChiefEngineerId() {
        return chiefEngineerId;
    }

    public void setChiefEngineerId(Long chiefEngineerId) {
        this.chiefEngineerId = chiefEngineerId;
    }
    public String getChiefEngineer() {
        return chiefEngineer;
    }

    public void setChiefEngineer(String chiefEngineer) {
        this.chiefEngineer = chiefEngineer;
    }
    public String getDesigner() {
        return designer;
    }

    public void setDesigner(String designer) {
        this.designer = designer;
    }
    public Long getProjectManagementId() {
        return projectManagementId;
    }

    public void setProjectManagementId(Long projectManagementId) {
        this.projectManagementId = projectManagementId;
    }
    public String getProjectManagementName() {
        return projectManagementName;
    }

    public void setProjectManagementName(String projectManagementName) {
        this.projectManagementName = projectManagementName;
    }
    public Long getConstructId() {
        return constructId;
    }

    public void setConstructId(Long constructId) {
        this.constructId = constructId;
    }
    public String getConstructName() {
        return constructName;
    }

    public void setConstructName(String constructName) {
        this.constructName = constructName;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public String getClassification() {
        return classification;
    }

    public void setClassification(String classification) {
        this.classification = classification;
    }
    public String getExecuteState() {
        return executeState;
    }

    public void setExecuteState(String executeState) {
        this.executeState = executeState;
    }
    public String getReviewRequirement() {
        return reviewRequirement;
    }

    public void setReviewRequirement(String reviewRequirement) {
        this.reviewRequirement = reviewRequirement;
    }
    public String getEdition() {
        return edition;
    }

    public void setEdition(String edition) {
        this.edition = edition;
    }
    public Long getCompilePerson() {
        return compilePerson;
    }

    public void setCompilePerson(Long compilePerson) {
        this.compilePerson = compilePerson;
    }
    public String getCompilePersonName() {
        return compilePersonName;
    }

    public void setCompilePersonName(String compilePersonName) {
        this.compilePersonName = compilePersonName;
    }
    public Long getCheckPerson() {
        return checkPerson;
    }

    public void setCheckPerson(Long checkPerson) {
        this.checkPerson = checkPerson;
    }
    public String getCheckPersonName() {
        return checkPersonName;
    }

    public void setCheckPersonName(String checkPersonName) {
        this.checkPersonName = checkPersonName;
    }
    public Long getApproverPerson() {
        return approverPerson;
    }

    public void setApproverPerson(Long approverPerson) {
        this.approverPerson = approverPerson;
    }
    public String getApproverPersonName() {
        return approverPersonName;
    }

    public void setApproverPersonName(String approverPersonName) {
        this.approverPersonName = approverPersonName;
    }
    
}

==> ejc-ztpcct-impl-3.0.0-20240428.030022-123-sources.jar: com/ejianc/ztpc/bean/ConOrgDesignPlanEntity.java <==
package com.ejianc.ztpc.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 施工组织设计清单表
 * 
 * @author generator
 * 
 */
 @TableName("ct_con_org_design_plan")
public class ConOrgDesignPlanEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="code")
    private String code; // 施工组织设计编码
    @TableField(value="name")
    private String name; // 施工组织设计名称
    @TableField(value="bill_state")
    private Integer billState; // 单据状态
    @TableField(value="project_id")
    private Long projectId; // 项目ID
    @TableField(value="project_code")
    private String projectCode; // 项目编码
    @TableField(value="project_name")
    private String projectName; // 项目名称
    @TableField(value="org_id")
    private Long orgId; // 项目组织ID
    @TableField(value="org_code")
    private String orgCode; // 项目组织编码
    @TableField(value="org_name")
    private String orgName; // 项目组织名称
    @TableField(value="parent_org_id")
    private Long parentOrgId; // 父级组织ID
    @TableField(value="parent_org_code")
    private String parentOrgCode; // 父级组织编码
    @TableField(value="parent_org_name")
    private String parentOrgName; // 父级组织名称
    @TableField(value="engineering_type_id")
    private Long engineeringTypeId; // 工程类别
    @TableField(value="project_leave")
    private Long projectLeave; // 项目分级(自定义档案)
    @TableField(value="compile_person")
    private Long compilePerson; // 编制人
    @TableField(value="compile_person_name")
    private String compilePersonName; // 编制人名称
    @TableField(value="approver_person")
    private Long approverPerson; // 批准人
    @TableField(value="approver_person_name")
    private String approverPersonName; // 批准人名称
    @TableField(value="state")
    private String state; // 状态
    @TableField(value="state_name")
    private String stateName; // 状态名称
    @TableField(value="con_org_design_type")
    private Long conOrgDesignType; // 施工组织设计类型--字典ct_design_plan_type
    
    
    

    public String getCode() {
        return code;
    }

    public void setCode(String code) {
        this.code = code;
    }
    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Long getParentOrgId() {
        return parentOrgId;
    }

    public void setParentOrgId(Long parentOrgId) {
        this.parentOrgId = parentOrgId;
    }
    public String getParentOrgCode() {
        return parentOrgCode;
    }

    public void setParentOrgCode(String parentOrgCode) {
        this.parentOrgCode = parentOrgCode;
    }
    public String getParentOrgName() {
        return parentOrgName;
    }

    public void setParentOrgName(String parentOrgName) {
        this.parentOrgName = parentOrgName;
    }
    public Long getEngineeringTypeId() {
        return engineeringTypeId;
    }

    public void setEngineeringTypeId(Long engineeringTypeId) {
        this.engineeringTypeId = engineeringTypeId;
    }
    public Long getProjectLeave() {
        return projectLeave;
    }

    public void setProjectLeave(Long projectLeave) {
        this.projectLeave = projectLeave;
    }
    public Long getCompilePerson() {
        return compilePerson;
    }

    public void setCompilePerson(Long compilePerson) {
        this.compilePerson = compilePerson;
    }
    public String getCompilePersonName() {
        return compilePersonName;
    }

    public void setCompilePersonName(String compilePersonName) {
        this.compilePersonName = compilePersonName;
    }
    public Long getApproverPerson() {
        return approverPerson;
    }

    public void setApproverPerson(Long approverPerson) {
        this.approverPerson = approverPerson;
    }
    public String getApproverPersonName() {
        return approverPersonName;
    }

    public void setApproverPersonName(String approverPersonName) {
        this.approverPersonName = approverPersonName;
    }
    public String getState() {
        return state;
    }

    public void setState(String state) {
        this.state = state;
    }
    public String getStateName() {
        return stateName;
    }

    public void setStateName(String stateName) {
        this.stateName = stateName;
    }

    public Long getConOrgDesignType() {
        return conOrgDesignType;
    }

    public void setConOrgDesignType(Long conOrgDesignType) {
        this.conOrgDesignType = conOrgDesignType;
    }
}
